@@ -1,7 +1,9 @@
 pub mod args;
 pub mod commands;
+pub mod core_parser;
 pub mod flags;
 
 pub use args::Argument;
 pub use commands::Cmd;
+pub use core_parser::Parser;
 pub use flags::{resolve_flag, Flag};
